pub struct SendAccessResponseModel {
pub object: Option<String>,
pub id: Option<String>,
pub type: Option<SendType>,
pub auth_type: Option<AuthType>,
pub name: Option<String>,
pub file: Option<Box<SendFileModel>>,
pub text: Option<Box<SendTextModel>>,
pub expiration_date: Option<String>,
pub creator_identifier: Option<String>,
}Expand description
SendAccessResponseModel : A response issued to a Bitwarden client in response to access operations.
Fields
object: Option<String>id: Option<String>Identifies the send in a send URL
type: Option<SendType>auth_type: Option<AuthType>name: Option<String>Label for the send. This is only visible to the owner of the send.
file: Option<Box<SendFileModel>>text: Option<Box<SendTextModel>>expiration_date: Option<String>The date after which a send cannot be accessed. When this value is null, there is no expiration date.
creator_identifier: Option<String>Indicates the person that created the send to the accessor.
Implementations
Sourceimpl SendAccessResponseModel
impl SendAccessResponseModel
Sourcepub fn new() -> SendAccessResponseModel
pub fn new() -> SendAccessResponseModel
A response issued to a Bitwarden client in response to access operations.